PHIL KEOGHAN: Previously onThe
Amazing Race... 13 formerBig
Brother contestants, paired with
their favorite traveling
companions, began racing in the
Netherlands.Two worlds
colliding right now in
Amsterdam. KEOGHAN: Dating
couple Kyland and Taylor won a
game-changing Express Pass...
-Thank you so much. -Thank you.
...and strategically handed a
second Express Pass to another
formerBig Brother winner.-Jag
and Jas. -Thank you. -Thank you.
KEOGHAN: A tandem bike ride
forced Angela to give up
control.You might be better at
driving a car, -but you're not
better at driving a freaking
bike! -[
[screams]
KEOGHAN: Two teams handled the
stress of being in the back very
differently.-I'm such an idiot.
-ALEX: Babe, you're not.
Everyone could have made that
mistake. MATT: Just got to keep
pedaling. It doesn't help that I
have the calf muscles of Woody
from Toy Story. KEOGHAN:
Brothers Jas and Jag set the
pace, narrowly beating brothers
Tucker and Eric.You are teams
number one and two. -Yeah! -[
[cheering]
KEOGHAN: Meanwhile, Jersey
brothers Enzo and Jack couldn't
overcome their hazard...Whoa,
whoa, whoa. Oh, oh, bro. -Get
out, yo. Come on, let's go.
-Come on. ...and were eliminated
from the race.-Horrible leg,
but we ended strong.
-Definitely. That's it. It is
what it is. KEOGHAN: Coming up
tonight, travel plans get
derailed.
[overlapping chatter]
We got off at the wrong station!
KEOGHAN: And Adam walks the
plank.I-I don't know.
[sighs]
♪
Route Info. "Travel by train to
Prague." KEOGHAN: All teams will
now take an overnight train from
the Netherlands through Germany
to the capital of the Czech
Republic-- Prague.
Regarded as Europe's most
walkable city, something teams
will be doing a lot of on this
leg of the race. -Let's go.
Let's do it. -All right, let's
do this. All right. Let's try to
find a taxi. We're brothers,
we're also best friends. And
we're roommates, we're also
business partners. So literally,
everything that we do, we do
together. We do together. We
grew up in Omak, Washington.
It's in the middle of nowhere in
Eastern Washington. JAG: Growing
up, we never had anyone in media
that we could look up to. For us
to be those people that, you
know, like, younger us's can
look up to,I think that's
pretty amazing. Do you know how
to get to Amsterdam Centraal
Station? Yeah? Tucker and Eric
are right behind us. -"Travel to
train to Prague..." -Prague!
BOTH: "...the capital of the
Czech Republic." Let's get it.
Let's get it. We're going to
Amsterdam Centraal Station. -All
right, let's get it. -Yeah,
let's do it. And we know we're
trying to go to Praha Railway
Station. So hopefully, we're
able to find something, um, that
gives us at least some lead over
the other teams. All right,
let's do this. -Bye. Thank you
so much. -Thank you so much.
TUCKER: I know we're doingThe
Amazing Race and everyone wants
first, but we're playing with p
Big Brother players, so there's
a lot of scheming and working
around stuff.All the teams seem
pretty competitive right out of
the gate. We lined up pretty
quickly with Jas and Jag.
TUCKER: They know how to play
this game. They know how to win.
Jag has won before onBig
Brother. So I think that we just
stay tight with them.
-Hi. -Hi. We are looking to get
train tickets to Prague. We need
to buy tickets to Prague. IZZY:
I have not been to Prague
before, but I've worked in the
past with a lot of musicians
from Prague. We're good
millennials, and we met online.
Swiped right. -The rest was kind
of history. -PAIGE: Yeah. IZZY:
And we realized that we wanted
to do life together. I'm a
professional flutist. I have no
memories before playing the
flute. PAIGE: I'm a lighting
designer for theater and live
events.We're really hoping to
be underestimated by the other
teams. We don't look like
athletes because we're not.
IZZY: We're gamers through and
through, and we would love to
exploit everyone's low
expectations of us.But we
really, really, really want to
win. I just hear it's beautiful.
So, yeah, I'm really stoked to
finally get to go and see it and
explore. Getting there earlier
will give us a better head start
-and better buffer of time.
-Yes. To get to the tower.
-Yeah. -Yes. STEPHANIE: I think
the strategy for today is to
just kind of center our nerves a
little bit, and I think we
should be good. We're in a
decent position, obviously, in
the middle, but our plan is to
get up front today.
That's the one. That's the one
that we'd like.
-In Dresden, yes. Thank you.
-Okay.
Dresden to Prague, and that's no
stops? Come on.
Yeah. Perfect. ERIC: We just got
the tickets that we were hoping
for from Amsterdam to Dresden, a
layover in Berlin. -TUCKER: Yup.
-And then we're going to be
spending the night in Dresden,
but then hopping on a 7:00 a.m.
train from Dresden to Prague.
-Thank you. Perfect. -Perfect.
-Thank you. -Thank you. Let's
go. ERIC: We feel pretty
confident.From here on out,
we're, we're coasting. Coasting
in Prague, baby. -Coasting in
Prague. -Let's get it. ♪
I know that Bohemia is in the
Czech Republic, like "Bohemian
Rhapsody." I'm two years older,
but we have not spent more than
three weeks together under the
same roof since I was 12 and she
was nine. When I was 12,I was
accepted into a boarding school
for students that are gifted.
Graduated from college at 19,
got my master's in three years.
Now I'm in my third year of med
school, and I'm 24.This race,
I'd say, represents us making up
for lost time.
We're hoping placing eighth will
slightly disarm. So now, at this
point, we slowly want to climb
the ladder and creep up behind
these other teams.
I mean, look, we got the Express
Pass. So when it comes to
actually getting challenges
done, like, we're solid there. I
feel really confident.
Just curious if everyone's gonna
end up being on this. Thank you.
Love you. Thank you, Love and
appreciate you. -Say thank you.
-Thank you.
-Thank you. -CHELSIE: Thank you!
You're awesome! Thank you so
much!
Are you guys on this train?
What's up? Yeah, we're getting
on this one. Is this what y'all
are doing? -Yes, that's the one
we're on. -Okay. Yeah. -PAIGE:
Yeah, get on in here, boys.
-Let's get on. Right on. Pop a
squat. -Yay. -Yay. -Yay. -Oh, my
God. -Breakfast. I'm sweaty. Of
course there's friendly
competition between me and
Tucker. Even though that is my
boyfriend,we know we love each
other, and whatever happens in
this, we're running our own
race, they're running their own
race, and that's fine.-We're
here? Okay. -Yes, this is it.
Yes, please. Thank you so much.
Man, we are working some magic.
HANNAH: Joseph and Adam are gems
of human beings. I have a great
relationship with them outside
of the race, outside ofBig
Brother. This race is notBig
Brother. But at the same time,
you can't completely run this
race alone. You're gonna need
some help, so, really thankful
to Joseph and Adam for kind of
giving us that boost,and all
four of us made that train.
-Group hug! -HANNAH: Group hug!
Yeah! ADAM: Good job! KEOGHAN:
These eight teams will be
traveling together from Berlin
through Dresden to Prague.
-Oh. -Is it? -Yeah. -LEXI: I'm
so excited! -What is special
about Prague?
I love ice hockey and the men,
too.
-ANGELA: Okay. A little too old
for her. -No. You would date
somebody over the age of 30?
-Yeah. -Oh, my gosh. She's never
had, like, a full-fledged
relationship boyfriend. -No?
-Never. And she's 24. But
she's-- yeah, she's very picky.
You make it sound like it's a
bad thing. It's not a bad thing.
I'm proud of you. We're going to
Prague, Czech Republic! -I'm so
excited. -Ah. I've been there
once for, like, a couple of
hours. Oh. We have a leg up in
the competition. No, we do not.
I was there for a couple of
hours. -I have a professional.
-I actually got sick, -so it was
not good. -Oh, uh... -Um...
-We... I have a professional.
-KYLAND: This is international
tickets. -TAYLOR: There we go.
We need the tickets to Praha,
Prague. I think we had some
friends come through.
-Yeah, let's go! -Amazing. Yes!
MEGAN: Reading comprehension is
both of our not-strong suits, I
guess. Yeah. When I was a kid, I
just was always put in, like,
the other classrooms to get help
with reading, reading comp... As
was I. In my head, we have a
perfect relationship. MEGAN: We
do have a very specific method
to solve any of our
disagreements.BOTH: I'm right,
you're wrong, and that's okay.
MATT: I'm very impulsive when it
comes to life in general. And
because of that, I don't read
directions extremely well. I
like to kind of take my own
path. MEGAN: I'm more of the
follower, and I like to stick to
the rules.He's more, "Let me do
what I want." -We're using our
brains. -Sort of. -Or we're each
using a quarter of our brain.
-Quarter.
That's how it's done. That is
how it's done. -KAT: What time
does that get us there? -9:23.
All I heard was that we're going
to get there at the same time as
the team before us. -KYLAND: If
we catch up... -TAYLOR: If we're
caught up to the rest of the
teams,we have a fighting shot
at getting in the starting pack.
-Ooh-ooh. -Ooh-ooh. KEOGHAN:
These three teams will be
traveling together through
Frankfurt to Prague.-Nothing
else? -So the earliest is 10:00,
and then it goes to 12:00.
MEGAN: Supposed to arrive at
with the 7:00 p.m. Okay, we'll
do that. Ah! Just because we're
last right nowdoesn't mean
we'll be last at the end of the
leg. KEOGHAN: Megan and Matt
will be traveling alone through
Regensburg to Prague.
[train whistle blows]
-Let's go. -All right. Let's
figure this out. We have 28
minutes until our next train.
What are we doing? RUBINA: We're
going to Berlin Gesundbrunnen.
ERIC: Yeah, so we got to get to
platform seven. We're supposed
to go to platform seven, right,
guys? There's no seven. We're
all lost together. Guys, we need
to hurry up. I have a funny
thing. Berlin... -Gesundbrunnen.
-Gesundbrunnen? PAIGE: Berlin.
Did we herd-mentality off at the
wrong Berlin stop? STEPHANIE:
Did we get off at the wrong
station, dude? JAS: Did we get
off at the right? We're in
Ber... No, yeah, we're in
Berlin, it says.
[overlapping chatter]
We got off at the wrong station.
-Why are you guys running? -We
got off at the wrong stop! We
got off at the wrong station!
-No. -The train's gone! The
train's gone! This is not
happening. Okay, we got... all
got off on the wrong stop, like
a bunch of idiots. -[
[sighs]
-This is a nightmare.
[train whistle blows]
We are going to Prague. -KAT:
Wow, this is beautiful. -Yeah,
this is... Wow. -We're gonna get
off. -We're gonna get off.
-TAYLOR: Thank you. -ALEX: Um...
-Yeah, let's do a croissant.
-ANGELA: Oh, look who just
walked in. How long have you
guys been here? We have an hour
and ten minutes left, so...
-Yeah, same. -Same. Have you
seen anybody else? -No. -No, you
guys are the first faces we've
seen today. ALEX: We're going
Frankfurt to Prague.I'm just
hoping we may get there, and
there's still some teams there
-that we can catch up to. -Yeah.
JAS: All the teams got off at
the wrong station. All we saw is
"Berlin," but it's the wrong
Berlin station.We needed to, I
think, go to another-- one more
stop. We're not gonna go mob
mentality. We're gonna find the
tickets. Okay, this has been a
joy. Do we have a plan? -Yeah.
-So we're gonna hop back on the
same train and just get off on
the right stop. Yeah, and then
we'll figure out the next
connection -from there. -That's
what I saw, too. -Oh, geez. -[
[laughs]
-Idiot! Idiot! Idiot! -Idiot!
Idiot! We were feeling pretty
good about getting to Prague at
the originally scheduled time,
but just a little bit of a
detour. IZZY: Let's get on. -By
the door. -Yeah, I'm sitting
right by the door. Ay-ay-ay. One
stop away. TUCKER: Yeah, we lost
three teams. RUBINA: So smart.
STEPHANIE: We're here with Jag
and Jas, Adam and Joseph.We
don't see any of the other
teams, so I assume that they
already got on another train.
This gets you there at 8:00 a.m.
That's not bad. I don't think we
do this solo. -We ask... Jag?
Jas? -They're upstairs. Let's go
ask 'em. You think the team got
on the earlier train? -Yeah. -So
they lost the connecting one.
They need new tickets. What
we're gonna do is, we found
tickets straight to Prague that
you can buy here. That gets you
there at 8:00 a.m. That gets us
there at 8:00 a.m. So if you
guys want to do that with us,
-that's what we're doing. -Yes,
do it! Whoo! ADAM: We might be
up big-time, boys. Was this
a...? JOSEPH: A blessing in
disguise? So, the original
tickets we had would have got us
into Prague at 9:22.These new
tickets get us into Prague at
thing, and it got us here. Let's
stick together till we get to
the next leg, please. -Can we do
that? -Yeah. We'll do that.
-This is our train, guys. -I
feel like... -This feels like
The Amazing Race.-This is The
Amazing Race.-Yeah! -[
[overlapping chatter]
-[
[hooting]
-Missing trains! -Yeah! All
right, everyone together?
IZZY: Seems like this way.
PAIGE: We lost ourselvesan
easier train night, but I think
we have ourselves back on track
to get that train from Dresden
-to Prague. -IZZY: To Prague.
PAIGE: But we haven't lost
ourselves any time off of our
expected ETA -since we left
Amsterdam. -IZZY: Yeah.
We're double-checking to see if
our train is still here. So, the
train was showing up on here for
the past 30 minutes. -TAYLOR:
Let's-let's go... -And it's not
showing up here? We've been
waiting out here for our train.
And we saw that it was delayed
by 18 minutes, then 24 minutes.
And now we're not even seeing it
-on the screen at all. -On the
screen. Do you guys speak
English? We're waiting for
Prague. ANGELA: What? It's
canceled? Yeah. Ooh!
[laughs]
-Oh... my gosh. -Okay. We had a
leg up. Now it looks like we
have a leg down.
The train to take us to Prague
has been canceled, um, and we
are looking up other options.
The Frankfurt disaster. I'm not
even sure when we will arrive
tomorrow. All I know is, I've
got comfort knowing we've got
two other teams, but they're
strong teams. So that's kind of
nerve-racking, too. There's the
train from Amsterdam to Prague
that has a stop off in
Regensburg. So that may be our
next best bet.
-[
[train whistle blowing]
-MEGAN: Some negatives turninto
positives. Some things that seem
bad at first aren't always so
bad. And maybe the teams that
got the earlier trains got
delayed. Right.
JAS: We made it.Woo-hoo! -Let's
go, teams. Let's go. -Come on,
guys. -Let's get it. -It's here
on the right. All right,
Underground Metro C. Let's go,
let's go. -Is this it? Is this
it? -C. Metro C. -Metro C.
-NATALIE: Museum A. -C to A.
Let's go. -ADAM: C to A. Let's
go. STEPHANIE: "Take the metro
and then travel by foot to the
television tower in Zizkov."
-Let's go, let's go. -Let's go.
JOSEPH: Let's do this.
RUBINA: 459? Yeah, this is it,
guys. EC 459. -Oh, man. We
finally made it. -KRISTINE: Hey,
well... -RUBINA: To Dresden.
Dresden. -KRISTINE: Dresden.And
now we're finally making it...
And now we're finally on our way
-to Prague. -...to Prague. We're
on a train. -We're on. -We're on
a train to Prague.
-Ground down? -No, that's not
a... -That's not a thing. -Okay.
Hopefully, some teams are too
worn out to think straight.
All right. All right, let's go.
NATALIE: We're here.
JAS: Clue box. Clue box.
ADAM: Oh, my God. Oh! Oh, my
God. -JAS: We're teams one, two
and three! -One, two, three.
Beautiful. -Roadblock.
-Roadblock. Let's go. All right,
we're team two! -Oh, Roadblock.
-Roadblock. -BOTH: "Who wants a
breath of fresh air?" -I do.
-Let me do it. -Are you sure? It
might be a physical thing. Yeah.
Let me do it. I'm fine. Teams
will begin their adventure here
in Prague with a bird's-eye view
from the city's tallest
landmark, Zizkov Television
Tower, famous for the crawling
babies that Czech artist David
Cerny attached to the tower.
This Roadblock requires teams to
walk out on this narrow plank
hundreds of feet above the
ground to pick up a clue
dangling precariously below.
Anyone scared of heights is
gonna have to take a deep breath
before they attempt this one.
-Let's go. That's perfect.
-That's perfect. That's perfect.
-Oh, my God. -Um... It's all
right. It's all right. NATALIE:
It's heights. I can't do it.
-I'll do it. I'll do it.
-NATALIE: Okay. -Oh, my God,
Adam. -NATALIE: Oh, my gosh.
Guys, we did it! -JAS: Let's go!
-NATALIE: Let's keep up the
three!
JAG: Oh, my God.
ADAM: What the hell?
JAS: What? -Let's go. -Oh, I'm
so jealous. -Jas. Nice to meet
you. -Whoo! Oh, my God.
-STEPHANIE: Oh, my God.
-NATALIE: What the hell? I don't
like using the word "afraid,"
but I think, looking out here,
we're going to use the word
"afraid." Yeah, chug that orange
juice, baby. Chugging orange
juice. As a type 1 diabetic, my
pancreas does not produce
insulin. So that means that I
have to continuously monitor my
blood sugar. I think this is the
perfect opportunity to show this
isn't gonna be something that
holds me back but something
that's gonnamotivate me and
motivate us to go all the way
and win. My sugar might drop,
but this is a real drop, so
orange juice is needed now.
We've maybe made it to Prague.
We can see the Zizkov Television
Tower from the train. -There it
is. There it is. -There it is.
There it is. RUBINA: It looks
taller than it did on the map.
MAN: So everything is clear?
-Yes, everything's clear. We're
good to go. -All right.
-STEPHANIE: No nervousness,
okay? -Okay. You got this. All
right. You can go on the
platform. Yes, sir.
[chuckles]
Wow. This is beautiful. Oh, my
God.
This is whyThe Amazing Race is
such a unique experience,
because no one else gets to
experience such thing.This is
Good luck.
[sighs]
I should have let you do this.
You can step on the platform
now. Now stay with me here,
please.
JAG: Come on, Jasu. Let's do
this. -You're ready to go.
-Ready to go?
Oh, my God. JAG
[laughs]: Let's go!
-Oh.
[sighs]
-Jasu, you got it. You got it.
Ooh!
Come on, come on, come on.
JAS: Red one first. Wow. There's
a cemetery right below me, so I
guess that's fitting if I fall
off. Oh, my gosh!
MAN: It's up to you. You can go.
I-I don't know. JOSEPH: You got
it. Don't overthink it, Adam.
Don't get in your head. I wish I
could take his spot. I know he's
terrified of heights.
[sighs]
You're clear and good to go.
NATALIE: So proud of you, Steph.
-STEPHANIE: Ah. -You can do it,
sissy. STEPHANIE: Oh.
Oh, my God.
JOSEPH: Adam, you're perfectly
fine. ADAM: I thought, "Oh, my
God." There was no way I was
doing this.-[
[sighs]
-JOSEPH: Walk forward.
[sighs]
JOSEPH: I know you're fighting a
fear now. Just don't get in your
head.
There you go.
Step by step. That's it.
Okay, coming up. I don't know if
I can. Wow. Look at that. Okay.
-Just like that. -And done! Like
cake, like cake. -You crushed
that. -Hey, come on. Yo, that
was gorgeous.
JOSEPH: You're k*lling it,
buddy.
NATALIE: Yay!
Good job, sissy.
That's my sister. That's my big
sis. -Route Info. -Route Info.
This is Prague's most famous
landmark-- the Charles Bridge--
with more statues than any other
bridge in the world.
Teams must figure out that their
next clue is on the east side of
the bridge, next to a statue of
the bridge's namesake Emperor
Charles IV.
"Take the underground metro and
then proceed on foot." Okay,
let's go. NATALIE: Slow and
steady. Good job, sissy! Yay!
Good job, good job. We'll see
you down there. -Okay, bye,
guys. That's my girl. That's
my... -[
[sighs]
-That's my sister. -Whoo!
JOSEPH: Yup. There we go. Oh, my
God. There's that clue, baby! I
am so proud of you. Let's go!
I'm coming. Okay. Let's go.
I'm in Prague... on a building.
Oh, my God, get me off. -Whoo!
-JOSEPH: Baby! -Let's go! -Let's
go! Let's go, baby! Oh, my God.
Oh, my God, I did it. You did.
That was so .... I think this
might be our train. MEGAN: We
have not seen any other team
since the last leg.
-[
[gasps]
-[
[Matt gasps]
MEGAN: I saw Kyland and Taylor
and then Alex and Kat. And then
I see Lexi and Angela, and I'm
like,"Oh, my God, there's three
teams right now on the same
exact train as us." There's not
one team. There's three here.
MATT: That was the momentwe
found hope again.
Three blocks? We got directions.
You guys start jogging.
-NATALIE: We're slow. Let us...
-Yes. Yeah, yeah. -Okay. -You
guys start jogging. The boys
have our back, 'cause they know
that we can't keep up with them.
Nat hasn't been on Big Brother
for years. I've never been on a
TV show before, so we're just
like sitting ducks in a way.
NATALIE: This is the season
where the win is going to be a
big win because this is the most
competitive people. Three
winners ofBig Brother? Are you
kidding me? So it's really nice
knowing that we can trust Jas
and Jag and also Joseph and
Adam.-Hurry up. Come on. Come
on. -Hey, we have directions.
-Run! -Run! Run! -You guys
waited.
[laughs]
Ah! Let's go. Come on, baby.
Pulan, I'm right behind you.
Okay. IZZY: Good job. We need to
get to the Zizkov Television
Tower.
CHELSIE: Dad! Hannah and Simone
didn't make it? Hannah and
Simone are somewhere else. Did
you see them? I wonder if that's
it. This? The swirly here?
-Excuse me. -Hello. Hi. Hello,
hello.
[speaks Czech]
Metro. -Metro? -Yeah... -Hlavní
Nádrazí. -Hlavní? -Yes. -This is
Central Station. -Yes. -And this
is metro inside. -Wait. Hlavní
Nádrazí is inside? -Yeah.
Yeah.
Go, go, go, go! -ADAM: So now
we're headed? -JOSEPH: Karluv
Most. -STEPHANIE: It's a bridge.
-Yeah, it's a bridge.
JAG: There? See it? -Oh, we see
it! -Spotted! Spotted! -ADAM:
Come on, Joseph! -JOSEPH: They
found it. I see a clue. Let's
go. Detour. KEOGHAN: Prague is
world-famous for its pubs, and a
hot favorite is U Fleku,that
has been serving and toasting
patrons for more than 500 years.
This Detour requires teams to
study the 11 village crests on
this tapestry, then search for
them in Knights' Hall on the
back of the dining chairs. The
names of each village are
displayed on the front of each
chair, which teams will need to
commit to memoryand then make
their way to the back of
Knights' Hall, where they must
recite the names of the villages
as a historian points to each
village crest. Czech glass, or
as it's commonly known, Bohemian
glass, is internationally
recognized for its distinctive
designs, quality, craftsmanship
and beauty.This Detour requires
teams to pick up 48 of these
affordable national treasures
and then deliver them to three
vendors. Once they've collected
stamps from all of them, they
can hand them over for a clue.I
think we're gonna do Handle with
Care. We should all do this.
BOTH: "Remember the Chair or
Handle with Care." Jag, Jas,
what are you guys thinking?
We're thinking Handle with Care.
How good's your memory right
now? Natalie and Stephanie,
we're gonna go with Handle with
Care. We're gonna go with Handle
with Care. -Let's go. Yeah.
-We're gonna do it. -Let's go.
-JAG: Now, this is -The Amazing
Race,baby! -Dude, look at that
view! Dude, this is gorgeous!
-There it is. There it is.
-There it is. TUCKER: Take the
next number-- four. Yeah, so
those guys made it somehow.
-"Who wants a breath of fresh
air?" -Me. -You got it, Tuck.
-Me. A breath of fresh air.
"Walk a plank 250 feet above the
ground and receive your next
clue from a dangling rope"?
-Let's go. -Shut up. Oh, right
there? Done. ERIC: Go get it,
baby. "Who wants a breath of
fresh air?" -You? -Uh, I'll do
it, yeah. I want a breath of
fresh air. She wants a breath of
fresh air. I love her so much.
-You do. -I do. -You want a
breath of fresh air. -I want a
breath of fresh air.
Ooh, let's go. ERIC: Look at
this view. TUCKER
[laughing]: I know. This is
sick. No fear, ready to rock.
CHELSIE: Oh, God, this is
iconic.
-JAS: Is it here? -It's right
here. There's a sign.
Right here, guys. Here. Kavárna.
Yeah, this is it. Don't
second-guess us. Come on.
JAS: Hi. How's it going?
Oh, this is where we have to
travel. NATALIE: "Choose two
crates to carry your goblets.
"When you think you have
collected all the goblets,
deliver them to locations on
your order forms." Okay, let's
go. There's very specific orders
on what number of goblets and
what color they want. So we're,
right now, filling all of those
up. There's 24 slots in each. To
keep this organized, all-- Adam,
not like that.
-[
[Natalie shrieks]
-I got it. TUCKER: Whoo-ee!
That's gonna be crazy. -Yeah,
you got this, Tuck. -k*ll it.
There's just a graveyard right
down there. It's like, "All
right, well, you know,"if
something goes wrong, at least
I'll land in the right place."
[laughs]
MAN: You're ready to go. TUCKER:
Let's do it. ERIC: Let's go,
Tucker!
Ooh.
ERIC: You got it, Tuck.
Damn it! He's crushing it right
now. He made it over there. No
hesitation. Maybe it's the hard
part. He's got some great
balance.
And he's back on the tower
already, baby! -Let's go. -ERIC:
Let's go!
-Mom's gonna have the willies!
-[
[laughs]
All right. "Make your way to
Krizovnické Námestí to find your
next clue." CHELSIE: You got
this, Dad. JACK: Okay. Being a
firefighter, you can't be afraid
of heights. I've been a
firefighter for the past 31
years. CHELSIE: Growing up with
a dad who's a firefighter, it
was fun because we got to brag,
"Our dad's a firefighter. Oh, my
gosh." -But on the other hand...
-[
[laughs]
...he would come... He would see
a lot of things on the job. He
was overly protective.We
haven't had a real Christmas
tree since 1996.
JACK: Ready.
CHELSIE: Nice. Nice and steady.
-Oh, my God. Oh, my God. -Hi.
-Hi. -Hi. -How you doing?
CHELSIE: Good job, Dad. We're in
a good spot.
Just take your time. -Oh, oh,
oh. -You call this a Roadblock?
-Let's go. -What? This is not a
block. This is just a road,
baby. -Right. -Thomas, do you do
this a lot? -Yeah. -Okay. And so
far, so good? You're still
alive? -Of course. -Yeah. Okay,
great.
"Who wants a breath of fresh
air?" -I'll do it. -You got it.
So, three red, two blue, three
yellow. Nat, what page are you
doing? Kafe & Hrnky. This is
purple, so we need a blue. -Are
you sure this is purple? -What
else is purple? Oh, my God, I
missed so many. -Nat, I need you
to focus. -I am. -Okay... -We're
gonna start getting directions.
Let's get outside. JAG: We
counted everything,
double-checked. And we're out of
there beforethe other two teams
that we're working with.
NATALIE: Oh, my gosh. Come on.
Does someone speak English here?
Oh, my God. -Okay. -Can we use
your phone for directions? We
need three different locations.
So let's start with this one.
JAS: There were three different
locations, so we wanted to make
sure that the three locations,
we wentin order, most efficient
route. -A... -It's all on the
same street. -Let's go. Let's
go. Okay. -Let's go. Okay. Okay,
perfect. We're ready to go.
-Whoo! -Careful! Careful! -[
[cheering]
Yay!
-Good to go. -KRISTINE: You got
this, Pulan.
Slow and steady. You got this.
PAIGE: I'm doing it.
I'm doing it. Okay.
[sighs]
Okay, so now get the directions
-from here to the next... -We're
here. To number two. -Hey, guys,
are you...? -That's Kafe Hrnky.
Where'd Jag and Jas go? -They
already left. We got to go.
-They left.
Kafe "Henry," 224/25.
-Two-two... -Kafe "Henry" right
there.
JAS: Good job. Excuse me.
-Hello. -We have a delivery for
you. -We have a delivery for
you. -Of goblets. Hopefully have
the right colors. We
double-checked before we left.
Beautiful. Five purple. Correct.
-Yay. -Awesome. Thank you. -Can
we get a stamp, please? -Of
course. JAS: Thank you. -JAG:
Next, Neruda Café. -Thank you.
-Thank you. -Thank you so much.
KRISTINE: Slow and steady. You
got this.
I can do this. I got this.
You did so good. -That was
excellent. -That was fun. No
sweat. KRISTINE: She's doing so
good. She's almost done. Oh, I'm
so proud of her. -Yay! -[
[screams, laughs]
Wow. I didn't let out any
screams. You're ready to go.
HANNAH: Simone, please, no
talking.
-Excuse us. -Yeah. What's it
called? Uh, Café Neruda.
JAG: Oh, there we are. -Hi. -We
have something for you. -Okay.
-We have a special delivery of
colorful goblets. -Thank you.
These are for you to count. All
of them out. And there you go,
and then two of these.
-JAG: Perfect. -JAS: Perfect.
Thank you. And thank you for the
stamp. -Thank you. Bye. -Thank
you so much. -JAS: Whoo! -JAG:
Right there. Okay, let's go.
NATALIE: Neruda Café. Oh, here
it is. -Hi. -Hi. -Hello. We love
you. Yes, let's go! Oh, it's so
good to see you with all
these... We love Czech Republic.
[whooping]
Thank you for having us. Whoo!
We're ready. We're ready.
[whooping]
NATALIE: No, are we at the wrong
place? -Oh, we're not here. It's
not here. -No. Come on, guys.
Did he just pull us in here to
party? I cannot believe that guy
just pulled us in there. "Ah,
come on, come in." And we just
walked in.
You said you wanted a heights
challenge. Can't get higher than
Thank you, thank you. -That was
amazing. -She's a prima
ballerina.
-JAS: Hello. -JAG: Hello. -Hi.
-How's it going? -Hi, guys. -We
have something for you. -We have
a special delivery. -Do you have
the sheet? -Yes, we do. -Great.
-Two reds, a blue. -Mm-hmm,
yeah. Two yellows, three greens.
-Yeah. -And two purples. -Okay.
-JAS: Yeah! Thank you so much.
We go right back to where we
came. We might have to get
directions. STEPHANIE: It's
literally on this road. Are you
sure? Wait. There's Jag and Jas.
-Jag! Jas! -STEPHANIE: Jag! I
see them over there. Have you
delivered any? We haven't
delivered the first one yet. And
you skipped one right across the
street. Turn left. The sign is
kind of hard to see. -You can't
tell what it says. -STEPHANIE:
We passed the first? JAG:
Neruda, go in here. You don't
leave this street. JAS: All
right, good luck, guys. -JOSEPH:
Hello, hello. -Hi. -STEPHANIE:
Hello! -NATALIE: Hello! -JOSEPH:
Hello, hello. It's so good to
see you. We found one, thank
God. Slow and steady. -Three
green? -Three green. Gentle,
sissy. -ADAM: Thank you.
-STEPHANIE: Thank you. -Yes,
hello. Welcome. -Four red. Four
yellow, three green, six purple.
-Yeah. -[
[whooping]
STEPHANIE: Let's go. NATALIE:
Let's go, guys. Everybody burn
those butts.
All right. We've delivered all
your goblets. And we got 'em all
stamped. There you go.
-Oh, thank God! -Oh, let's go.
JAS: "Travel on foot to the
Josef Mánes statue outside the
Rudolfinum to find your next
clue."-Okay, perfect. Let's go.
-Let's go.
Here's one purple, one orange.
-STEPHANIE: Thank you so much.
-NATALIE: Perfect. Yay! Thank
you. Thank you. Two down, one to
go.
-We made it! -Okay, baby, let's
go. We made it to Prague!
TAYLOR: We arrive in Prague with
three other teams.We told
everyone that we were moving as
a unit to navigate to the Zizkov
Television Tower.One stop red,
transfer, three stops green. But
just horror shot through my
veins after realizing this could
be the final four teams, and one
of us is likely to be
eliminated. And we were just
immediately back fighting for
our lives.Fingers crossed that
there's a ton of clues left over
there and we're... -not in the
last group. -One of the first
teams.
KYLAND: All right, good luck,
squad. Let's get it. TAYLOR:
Let's move. ANGELA: Kyland and
Taylor, y'all are k*lling it
right now. Thank you. Excuse us.
You got it. ANGELA: Oh, my gosh.
-What's the name of the shop?
-Kafe & Hrnky. -STEPHANIE: Oh,
guys, it's in here. -ADAM: Yeah.
Let's start counting our
goblets. NATALIE: Let's go,
guys. Three red, two blue, three
yellow, two green, five purple.
Whoo! You are up, ladies. Two
blue, three yellow, two green,
five purple. And... Yes! Let's
go, sissy! -STEPHANIE: Thank you
so much. -NATALIE: Thank you.
Quick, quick, quick. Speed it
up. Come on, guys. We're on The
Amazing Race,not on The Amazing
Turtle.
[Joseph chuckles]
JAS: The no sleepis wearing on
me.
-Route Info. -Route info. "Race
to... on your Pit Stop." Let's
go!
Many of the world's greatest
composers, including
Tchaikovsky, have performed
right here at Zofín Palace. It
continues to host concerts,
ba*ls, and galas and today will
roll out the red carpet for an
Amazing RacePit Stop. The last
team to check in here will be
eliminated. -Okay. -Okay, we've
got to get some directions.
-Zofín Palace. -Let's go.
-JOSEPH: Oh, my God. -Hi.
JOSEPH: My vendor. NATALIE: Here
you go, kind sir. -Joseph, you
have all three? -All three,
baby. Please.
-Yes! -[
[cheering]
NATALIE: We love you! My good
sir.
-Yay! -Whoo! "Travel on foot to
the Josef Mánes statue and..."
BOTH: "...find your next clue."
-Okay. -Oh, my God. -TAYLOR:
Right. -KYLAND: Right here.
TAYLOR: Ninth.
[Kat panting]
I'm doing the Roadblock. -"Who
wants a... a breath of fresh
air?" -Me. Me. "Who wants a
breath of fresh air?" -You do.
-Okay. I'll do it. Mom, look
what I'm seeing up there. This
isn't a trick. -You do it.
-Okay. MAN: So, right here,
-facing my direction. -Facing
you. Cool. Now we will attach
first rope. Hey, what's up,
everybody? -[
[laughing]: Hey, what's up? -Oh,
God. MATT: This is crazy.
-I'll be safe. -Love you.
JOSEPH: Adam, come on. -[
[Adam sighs]
-JOSEPH: Statue should be there.
That's it. Jog. STEPHANIE: I see
a clue box. Clue box. -Come on,
Adam. -All right, let's go.
"Race on foot to your next Pit
Stop inside... to find Phil on
the mat." -Oh! Guys, we got to
go. -JOSEPH: Okay. Zofín Palace.
JAS: Let's go.-Right. -Yeah.
-Yeah! -Let's go! -Whoo! -All
right. Good job. Welcome to
Prague. -Thank you. Thank you.
Thank you. -Thank you. We love
it. Do you recognize this
gentleman? Uh, maybe a composer?
-He's Dvorák. -JAS: Dvorák. -We
were gonna guess that next. -Ah.
On the tip of my tongue. And you
are team number one. Let's go!
Let's go! And I do have some
great news for you. As the
winners of this leg of the race,
you have won OneKeyCash from
Expedia, which you could use
towards a trip for two... to Sri
Lanka. -Oh! -Oh! -JAG: Let's go.
-JAS: Let's go! KEOGHAN: Expedia
has designed a nine-day guided
tour around Sri Lanka with major
attractions, featuring a
Sigiriya rock climb, a scenic
train ride in Ella, a wildlife
safari in Yala National Park,
and... a cultural dance show in
Kandy.-Whoa! That's so cool.
-That's so cool. So if you were
to pick teams that you feel like
you were going to be racing with
later in the race, -who do you
think those teams are gonna be?
-JAS: Honestly, -the other two
teams that were with us...
-Helped a ton. ...Joseph and
Adam and Natalie and Stephanie--
helped a ton. JAG: We were
working together as, like, a
trio. And they're extremely
smart. So far, that's who we
feel good about.-This was it
right here. -That was the dome,
too. But you just clicked on the
area. -No. -And there was a
picture of something in the
area. -Oh, there's a clue box.
-I've been telling you.
Route Info. "Race on foot to
your next Pit Stop..." Oh, dude,
let's go. "...inside Zofín
Palace and find Phil on the
mat." Pit Stop? Are you kidding
me? Wait, we're already at the
theater?
[laughs]
-ERIC: Dude. -Zofín. I can't
believe it's the Pit Stop, bro.
I was expecting, like, two,
three more challenges. I was
expecting to go until, like,
Phil. Thank you. -Thank you,
Amazing Race. -Amazing Race.Oh,
giving us a little bit of a
breather.
-JOSEPH: Oh, yeah, these stairs.
-NATALIE: Oh, this is the
palace. JOSEPH: Phil! STEPHANIE:
Nat, run!
[Joseph and Adam laughing]
-Oh... my... God. -Oh. All
right, Joseph and Adam, I'm
pleased to tell you that you are
team number two. -[
[Joseph laughs]
-[
[Adam screams]
Natalie and Stephanie, that
would make you team number
three. -You're on the podium.
-Yes.
[cheering]
JOSEPH: Oh, my God, baby, let's
go.
[exhales slowly]
Not the cemetery below me. Geez,
guys.
Ooh. This is a lot harder than I
was expecting. Okay. Ooh!
Holy moly.
No reason to rush.
Okay. Whoa. All right. I'm,
like, questioning all my balance
right now.
I feel like... Yeah, you know
what? -Let's just take that.
-TAYLOR: Yes! Yes! -[
[sighs]
-Yes!
[whispers]: Kiss, kiss, kiss.
MATT: All right. This is
actually way scarier when I got
up here. If you need to, you
will just shout "Help."
-[
[cries]
-ANGELA: You got it! -I can't
believe I'm doing this! -ANGELA:
You got it.
[humming]
[whoops, laughs]
All right, I'm done. -Oh, my
God. -KAT: Thank you. Are you
kidding me? Are you kidding me?
"Make your way to Krizovnické
Námestí to find your next clue."
-Let's go. -Yeah, take those
off. Let's roll. -All right,
let's go. -Let's go. -Let's go.
-All right.
-MATT: This is scarier than it
looks. -MEGAN: It's okay. I just
need a second. I just know that
we're in last right now. You're
hooked up. You're hooked up. And
I feel, like, a lot of pressure.
-Don't feel the pressure. You've
got this. -Okay.
The second I move, I start
shaking.
Sorry. I'm sweating now, Megan.
I'm sorry. I feel like I'm gonna
throw up.
Dude, I'm gonna cry.
[sniffles]
Okay.
[breathing heavily]
Okay. Ooh. -Oh, my God. Oh, my
God. -ANGELA: Very good. Very
good, my dear.
[Lexi breathing loudly]
Oh, my God. -ANGELA: You got it.
-[
[panting]
ANGELA: You've got it. Just go.
You got it. LEXI: Okay.
Oh.
MEGAN: There you go!
It's okay. I'm right here.
You're safe. You're safe. Just
keep going. It's fine. Little by
little. -Megan, this is so
scary. -Little by little. There
you go. Just take baby steps.
This is not real. This is not
real. I don't think I've ever
felt, like, anxiety like this in
my life. Oh, my God, my legs
are, like, shaking right now. I
can't look. I can't look.
Mom, look at me. -[
[Angela laughs]
-[
[Lexi screams]
I'm so proud of you. Oh, my God.
Oh, my God. Oh, my God. -That
was so close. -Look at what you
freaking just did!
MEGAN: Yes!
Great work! -I'm so proud of
you! -Thank you. Keep going. I
need to hear your voice right
now. MEGAN: Oh, my gosh. Look at
you go! Okay, let's just get out
of here with that so far, okay?
MEGAN: Good job! Nice. Nice.
Nice. Oh, my God. I'm so proud
of you. I'm so proud of you.
That was tough. "Make your way
to the Krizovnické Námastí to
find your next clue." ERIC:
That's it. Zofín Palace, baby.
Hey. Whoo! Tucker and Eric,
you're the fourth team to
arrive. -Let's go, baby! -Let's
go. That's what we thought. Ah!
However, you have not completed
the Detour. So you need to go
back out onto the race course,
complete the Detour before I can
check you in.
Figure it out. Let's go.
Turns out the Pit Stop was too
good to be true. So we're going
to go find this Detour, baby.
-Aw, man. -Damn!
-PAIGE: This is it. -IZZY: Yeah.
Okay, do we see it?
-IZZY: There's a clue box!
-PAIGE: Where? IZZY: Right there
to the right. PAIGE: Let's go.
Love that. -Detour. -Detour.
"Remember the Chair or Handle
with Care." If we do this
together... -You guys. -We can
do it together. -RUBINA:
Together? -I do think -more
brains... -RUBINA: Will help it.
We're going to do Remember the
Chair. -We're gonna choose
Remember the Chair. -Remember
the Chair. Detour. "Remember the
Chair or Handle with Care." Hey,
guys, what are you doing? PAIGE:
Remember the Chair. We might as
well stay close to them and do
the Chair. Over there. RUBINA:
Hi, guys. -What? Let it go.
-Hell yes. -Okay. We got to
move. -We got to move. Detour.
Time for a little jog, guys. We
got to go. -All right, let's
take Remember the Chair. -I
don't care at all. -All right.
-RUBINA: We just saw Tucker and
Eric at the clue box, but they
were before usat the tower, so
guess what.
[laughs]
-[
[Kristine laughs]
-Okay. Love you. Sorry, Tucker,
if you're seeing this. -[
[Kristine laughs]
-Good job, babe. But we're doing
a gooder job.
[Tucker groans]
We should have known by Phil's
face when we walked in. No
smile.
No eyebrow up. -[
[laughs]
-Dang.
Detour. "Remember the Chair or
Handle with Care." -Remember the
Chair. -Always. Always. We're
really good when it comes to
memory stuff.
-IZZY: I'm dying. -RUBINA: This
is really hard. U Fleku. This is
it. This is it. Good job,
everyone. -PAIGE: Hello. -IZZY:
Hello.
Oh, here. Right here. IZZY: We
have to find these crests and
learn the names. PAIGE: Eight,
nine, ten, 11. Let's get a
rhythm of what we're supposed to
do. -Yeah, I know. Yeah. -Yeah.
CHELSIE: My God. IZZY: Oh, man.
Okay, let's do it.
Sorry.
[laughs]
KRISTINE: Sorry.
IZZY: Baby, I found the
sardines. -So now what do we do?
-Awesome. Uh, excuse me. Can I
ask you a question? How do you
say this? -"Ash." -"Ash."
-"Ash." -"Ash." -"Ash." "Ash.
Ash." IZZY: People were sitting
in chairs that had crests in the
back, so we had to learn how to
pronounce the names of these
towns and pair them with the
matching crests. And to do that,
it was a little bit like needle
in the haystack, finding the
crests and then asking these
awesome Czech peopletrying to
enjoy their lunch how to
pronounce the names and learning
them. -RUBINA: How do I say
this? -WOMAN: Yeah, like "Lito
Mish-la." -"Little Mish-la."
-"Mish-la." That's me. Little
Mish-la. Yeah. I'm so sorry. So
sorry. KRISTINE: It was very
instantly chaotic. Pulan? Look
for yours. I'm gonna keep going.
-Do you hear me? Hello?
-KRISTINE: Yeah. Yes! KRISTINE:
The six of us in the room
running through the chairs all
at the same time, learning the
pronunciation, so we're hearing
everybody's conversation.
"Brr-no. Brr-no." It was just
chaos.
[singsongy]: "Brr-no, Rye-rad,
Little..." All righty. All
right, we're here. -I need to go
find two flowers. -"Brr-no..."
CHELSIE: It was absolutely
chaotic. And then Eric and
Tucker show up.I was with
Tucker all summer for Big
Brother. The guy has a great
memory. So when he walked in
there, I was like,"Oh, Lord,
here we go." How do you
pronounce this one again?
-"Beel-chit-say."
-"Beel-chit-say"? Yes. It's a
tough one. -Repetition is key.
Repetition is key. -Yeah.
-"Freedland." -"Sha-bon."
-"h*-mu-tov." -Slow and steady.
We want to just do it right the
first time.
Okay, let's do it. RUBINA: You
got this. -Yes. -Yeah? -Yes. Go
on... yes, you got it. -Let's
try it. -Okay, let's try it.
-Yeah.
-Hi. -Hi. -Hello, welcome.
-RUBINA: It's in different
order, but that's okay. -Okay.
"Vish-kov." Oh, my God. Oh, my
God. Hold on. "Beel-chit-say."
"h*-mu-tov." "Little Mish-la."
"Rye-rad." "Ash." Um...
"Freedland." "Tre-bon-ye."
"Oon-ee-tov." "Bo-kov."
"Bo-ya-nov." I'm sorry.
Incorrect. -RUBINA: Oh!
-KRISTINE: Let's look again. -We
got this. -It's okay.
-"Se-bon-ye. Se-bon-ye." -MAN:
Okay. -WOMAN: "Se-bon-ye."
-HANNAH: Okay. "Se-bon-ye." I
think we're ready. Do we...? I
got it. I'm good.
-You got this. -I had it. It's
okay. Don't be hard on yourself.
"Hog-bov." Ah. I don't remember
this one, dude. "Bo-ya-nov"? I'm
sorry. Incorrect. TUCKER: Get
back! "Boy-chut"? And
"Bo-ya-chov." MAN: Incorrect.
"Bo-ya-nov." -MAN: Incorrect. -[
[Kristine groans]
-Okay. -That's okay. Don't
worry. Don't get frustrated. We
just have to keep trying.
-Oh, clue! -Yes! "Remember the
Chair -or Handle with Care."
-"...or Handle with Care."
-Handle with Care. -All right,
we'll Handle with Care. Um...
"Bo-kov." "Bo-ya-nov." MAN:
Incorrect. SIMONE: Really? Okay.
Thank you. -"Bo-hoff." -[
[bell dings]
-"Bo-ya-nov." -[
[bell dings]
-Sorry. Incorrect. -Ugh. -Hi,
sir. -Hello again. -Hi. -We're
back. -We're back. -Okay. Okay.
-"Bish-kov." -[
[bell dings]
-"Beel-chit-say." -[
[bell dings]
-"h*-mu-tov." -[
[bell dings]
-"Sech." -[
[bell dings]
-"Rye... Rye-rad." -[
[bell dings]
"Ash." -"Freedland." -[
[bell dings]
-"Tre-bon." -[
[bell dings]
"Brr-no." -[
[bell dings]
-"Bo-hoff." -[
[bell dings]
"Bo-ya-nov." Oh! Oh, my God! Oh,
my gosh! Thank you so much.
Thank you so much, sir. -Mmm.
-Aw. Me, too. Yay! Route Info.
Okay. "Travel on foot to the
Josef Mánes statue." -Remember,
we act like we're in last place.
-Yes.
-Hello! -Hello! -KYLAND: How's
it going? -TAYLOR: Hooray. "Ask
the shopkeeper for three order
forms." -Can we have three order
forms? -Can we have the order
forms, please? -Thank you. This
is one, two, three. -Thank you.
KYLAND: Goblets. Three red, two
blue, three yellow, two green,
five purple. Here's two green.
-Handle with care. -TAYLOR:
Careful, please. KYLAND: Yes,
sir. Sorry about that.
"Bear-no." "Bo-hoff." ERIC:
"Bo-ya-nov." -Yes! -Let's go!
-Let's go! -Thank you, sir.
-"Rye-rad." -"Rye-rad." -TUCKER:
Let's go! -RUBINA: Oh, they got
it. -Don't worry about them.
-Don't worry about them. -I'm
not. TUCKER: Come on, baby! You
guys got this. -Good job."
-"Sha-bon." -IZZY: Good job.
-ERIC: Keep hammering. At least
we know where to go. TUCKER:
Yeah. Exactly where we were.
-ALEX: This is amazing. -KAT:
Got it. Oh. Detour. "Remember
the Chair or Handle with Care."
I think we're better at
remembering. -Let's go. -Famous
last words. ALEX: We're gonna do
the Chair. -Two green? -Two
green. -Three purple? -Three
purple. Two... -One orange.
-That's one. Yes. Okay, perfect.
And then we need -to go to these
places. -Yes. -Ooh. -Okay, so we
need to find directions.
"Bo-hoff." "Bo-ya-nov."
-Incorrect. -[
[buzzer sounds]
[Rubina sighs]
We have to try something
different because we can't keep
trying the same thing. -That
one's mine, right? -Uh-huh.
Okay. "Bo-hoff."
"Bo-ya-nov." Perfect. -Go!
-Correct. -Thank you so much.
-Thank you so much. We are sorry
for what we did to your
language. It's beautiful. These
are beautiful. -PAIGE: One and
done. -IZZY: Yeah. We slayed
that. RUBINA: "Little Mish-la."
"Little Mish-la." I know this.
KRISTINE: The crests are
correct. RUBINA: I think the
crests are correct, too.
"Bear... Bear-no." "Bo-kov."
"Bo-ya-nov." -Yes. Thank you.
Thank you. -Amazing. -Can I hug
you? Yes. -[
[Jack laughs]
-KRISTINE: Pulan, they got it.
-RUBINA: Stop it. Stop it.
-KRISTINE: Everybody left.
-RUBINA: Don't... -Hey, we're
still ahead. -I know. I know.
Release the frustration, because
we're just trying to figure it
out. -Well, well, well. -[
[cheering]
Thank you. Thank you. Touched
it. We already got it. Yeah,
we're back. Okay, let's go.
-[
[Matt mutters]
-We got it. There you go. Oh, my
God. We're here. -Detour.
-Detour. Of course it is.
[panting]
We're going to do Remember the
Chair. We're going to do
Remember the Chair. Remembering
the Chair.
-We're still in this. -It's this
one. -RUBINA: Yeah? -KRISTINE: I
mixed it up. -You mixed it up?
That's okay. -Yes. What's this?
"Brr-no. Brr-no." "Brr-no."
-"Brr-no." Yes. KRISTINE:
"Brr-no." -Okay, I got it. -You
got it? -Yes, let's try it
again. -Let's try again.
"Brr-no." "Bo-hoff."
"Bo-ya-nov." MAN: Incorrect.
RUBINA: Don't get... It's okay.
Six tries later, we were still
getting it wrong. KRISTINE:
Getting it wrong.You're like,
"Why can't we get this and
everyone else can?" I feel like
I'm saying it exactly how
they're saying it. Right, so
then if you feel like you're
saying it right, there's
something else. "Bo-ya-nov."
"Little Mish-la." Take it easy,
take a breath.
I know. I'm just trying to... I
know. I just need quiet right
now.
I can get frustrated really
easily. It was just a
high-stresssituation. Sorry.
Incorrect. Incorrect. Sorry.
Incorrect.
Okay.
RUBINA: Let's try it. Let's
practice. -[
[gasps]
I know. -KRISTINE: What is it?
RUBINA: This one. I don't have
the gold one.
It was gold. -This one. -Oh, my
God. -WOMAN: "Sech." "Sech."
-"Sech"? "Sech"? KRISTINE: We
were thinking it was a
pronunciation,but in reality we
were choosing... RUBINA: The
wrong crest. So there were
similar ones, obviously. Ha!
Attention to detailin this
Amazing Race?That's new. No.
[quietly]: "Sech." -Do you know?
-Yeah. "Sech." KRISTINE:
"Rye-rad." "Ash." "Freedland."
KRISTINE: "Sha-bon-ye."
"Bur-no." RUBINA: "Bo-hoff."
"Bo-ya-nov." -Perfect. -Yeah.
I'm sorry. -I'm so sorry. I'm so
sorry. -So hard. -It's okay.
-I'm really sorry.
[applause and cheering]
-Thank you, thank you. Thank
you. -Thank you so much.
-KYLAND: Kafe! -TAYLOR: Yes! All
right. Go on in. -Hello! -Hi.
-Hi. We have a delivery for you.
-For you. KYLAND: We have three
red, two blue. Thank you. Three
yellow. Two green and five
purple. Correct. Thank you so
much. Thank you. I love your
hair. -Amazing. Thank you.
-Thank you.
We had to double back, we found
the right clue. -Yup. -We did
the Detour. Tucker and Eric, I'm
pleased to tell you that you are
now team number four. -Let's go!
-We stayed in fourth place!
-Let's go! -Let's go, baby. Now,
see, the ice cream is way
better.
We got ice cream and fridge
magnets to celebrate what we
think is maintaining our fourth
place, despite our blunders from
earlier. Kept the same place.
-KAT: All right. -ALEX: Okay.
I'll take... I'll take the red
and make it easy... -yellow and
green. -Okay. Let's just start
with the blue, and then we can
see from there, 'cause we might
have to change. -All right. -So,
fish.
KAT: Here, fishy. Fish? May I
ask you how to pronounce this?
-"Ash." -"Ash." So, "Ash, Ash,
Ash," fish. We can do it. This
is gonna be easy.
Hannah and Simone, I'm pleased
to tell you that you are team
number five.
[both cheer]
Here we go. Two green, one
orange, two red, two yellow,
three purple, one...
-Yes? Yes. Yes! -Thank you! All
right, babe.
-Thank you so much. -You, too.
TAYLOR: Back where we came,
remember? KYLAND: Yup. Exactly.
Hey, Joseph. There's still a
bunch left. -"Find Phil on the
mat." -Fine, let's go to the
mat!
Our greeter is playing the role
of a famous Czech composer. Is
it Dvorák? -Oh, my God. -Very
good. Yes!
[laughs]
Nice to meet you, Antonín.
-"Bo-hoff." "Bo-hoff."
-"Bo-hoff." ALEX: Come on. I
think other teams are right
behind us.
KAT: Oh, wow. -Okay. -Um, so...
Dude, I don't know...
"Freedland." "Tay-bon." Kat, can
you give us a clue on where we
go? I... I'm memorizing really
hard. I understand. Hello, sir.
How's it going? We got your
three stamps. -Ooh. Yes! Thank
you. -Thank you. DVORÁK: Welcome
to Prague.-CHELSIE: Thank you.
-JACK: Thank you, sir. Jack and
Chelsie, I'm pleased to tell you
that you are team number seven.
-Seven. -Seven. All right!
-Aren't you glad to see us?
-Aren't you glad to see us? -So
glad to see you. -Oh. Kristine
and Rubina, I'm pleased to tell
you that you are team number
eight. -Yes, we'll take it.
-Yes... It's okay. It's okay. We
knew it, we knew it, and we're
okay.
[Lexi mutters]
"Freedland." "Dose-a-bo-ya."
"h*-ma-dov." -Ugh. Ugh.
"But-kov." No, no, no. No "T."
ANGELA: Lexi, see if you can get
this. -"Bo-hoff." -"Bo-hoff."
-Yeah? Yeah? -Yes. Very good.
-"Bo-hoff." -You're doing good.
-I know. I don't know what's
happening. -Yeah. Let's go.
Let's go. -Hell yeah. Thank you,
guys.
You got it. ALEX: "Bo-ya-nov."
[Kat screams]
Gosh, thank you. Oh, my. Oh, my
gosh. Thank you. -Ah. -♪ Ah!♪
Oh, my gosh. I have mine, too.
Did you guys do it? You got
this. Just everyone talk to
themselves for now. LEXI: Kat
and Alex had left.It was very
stressful. We knew we were the
last two teams there. I'm sorry.
Incorrect. Incorrect.
-Incorrect. I'm sorry. -What?!
Incorrect. -Incorrect. I'm
sorry. -No! It was a very, very
tense situation. "Bo-ya-nov."
-Incorrect. Sorry. -Oh. -Oh.
This is, like, mentally breaking
me right now. If you think you
have what it takes to win The
Amazing Race,then go to
cbs.com/casting and apply now.
The world is waiting for you.
-Get in focus. -It's okay. -[
[crying]
-It's okay. It's silly. It's so
silly. -Damn it. It's so silly.
-We don't know the language. We
haven't slept in 48 hours. -We
got this. -LEXI: Okay. Megan, I
have been messing this up
drastically. TAYLOR: There it
is. "Race on foot to your next
Pit Stop inside Zofín Palace.
-Find Phil on the mat." -Yes!
Oh.
"Bo-ya-nov."
[both laughing]
It's an honor. Thank you.
[applause and cheering]
"Vish-kov." "Beel-chit-say."
MATT: This was yet another
instance where Angela and Lexi
finished before us.In that
moment it was make-or-break.
"Bo-ya-nov." -Correct. -Okay.
-We got it. We got it. All
right. -Thank you. -It says
"statue outside of the..." -We
got it. -Yay! -Yes! -We did it,
you guys. -And, guys, if it's
the Phil thing, we all just got
to run. We did it! -Oh, my gosh.
-Josef Mánes. -ALEX: Josef.
-KAT: Oh, my God. "Find Phil on
the mat." KEOGHAN: Kyland and
Taylor, I'm pleased to tell you
that you are team number nine.
All right. KEOGHAN: You are team
number ten. Congratulations. Oh,
my gosh. "Race on foot to your
next Pit Stop inside Zofín
Palace and find Phil on the
mat." So where is Zofín Palace?
Zofín Palace. Can we go with
them? It's... No. It's not over
till it's over.
[laughs]
MATT: We got to go. I can't be
loyal anymore. I'm fighting for
a million dollars for the
family. -MEGAN: Yes. -Not for
Angela and Lexi. ANGELA: We're
not done.
[sniffles]
We're not done. LEXI:
[laughs]
We're not done. MEGAN: I thought
it'd be on our right. -We can
ask maybe one more person.
-Right.
LEXI: We don't know what's gonna
happen. All we can hope right
now is that they couldn't find
this place. No matter what
happens, we're trying our best.
Trying our best. -LEXI: Is that
it? -ANGELA: It is, it is. MATT:
This has to be Zofín Palace.
Okay, this is it, Megan. One
more push up these steps. MEGAN:
I want to run to him, but I
can't. Phil, I'm coming for you.
MATT: Hey. -Oh, Phil. -KEOGHAN:
Wow. MATT: Oh, God, is it good
to see you. MEGAN: I'm so happy
to see you. Megan and Matt, I am
pleased to tell you that you are
not the last team to arrive. -[
[laughing]: Let's go. -[
[laughing]: Let's go. Oh, I'm so
proud of you. You are team
number 11. -Yup. -That's our
lucky number, Phil. That's our
lucky number. ANGELA: Give it
all you got. Come on. Come on.
-Good job. Good job. -LEXI: You
too. ANGELA: Thank you. Angela
and Lexi, unfortunately, you are
the last team to arrive, and I'm
sorry to tell you you have been
eliminated from the race. -It's
okay. -It's okay. It's okay.
LEXI: I'm really proud of her.
I'm beyond proud of my mom. You
know, she's 51 years old. She's
up against 20, 30-year-olds on
this race, and you're still
keeping up pretty good.
ANGELA: You know, I'm a mom, and
I kind of helicopter parent a
little too much. She's impressed
me,and I think moving forward,
it's giving me a newfound
respect for my girl, and I think
she does for me, too. LEXI: I
do.
So you're gonna take the AirTag
out of my car? No, I still need
to know where you are. -I'm
taking it out of my car. -You're
hundreds of miles away. -She can
trust me now. -She's hundreds of
miles away. She's hundreds of
miles away.
KEOGHAN: Next time onThe
Amazing Race... When the
Driver's Seat returns...Let's
strategize. KEOGHAN: ...the
plotting begins...Target's on
our back. -That works with us,
yeah. -We're trying to keep our
hands clean. KEOGHAN: ...and
shakes up the race.Aah! Once he
start spiraling, it's over. My
Lord.
I'm so over this.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
38x02 - Mom's Gonna Have the Willies
Watch/Buy Amazon Merchandise
Adventure reality competition franchise in which teams of two people race around the world in competition with other teams.
Adventure reality competition franchise in which teams of two people race around the world in competition with other teams.